@@ -18,11 +18,10 @@
 
 #include <QObject>
 
-class ScriptTest
-    :public QObject /* necessary to instantiate Kross::Action */
+class ScriptTest : public QObject /* necessary to instantiate Kross::Action */
 {
 public:
-    
+
     void test();
     void testJS();
 };
