@@ -18,7 +18,7 @@
 #include <keduvocdocument.h>
 #include <QObject>
 
-#include "../config-parley.h"
+#include <config-parley.h>
 
 class ParleyMainWindow;
 class QTimer;
@@ -30,7 +30,7 @@ class ParleyDocument : public QObject
 {
     Q_OBJECT
 public:
-    ParleyDocument(ParleyMainWindow* parleyMainWindow);
+    explicit ParleyDocument(ParleyMainWindow* parleyMainWindow);
     ~ParleyDocument();
 
 
@@ -85,7 +85,7 @@ public slots:
 
 signals:
     /** Emitted when the document pointer is changed.
-     @todo Stop using documentChanged(0) as a replacement for destoyed in editor classes.**/
+     @todo Stop using documentChanged(0) as a replacement for destroyed in editor classes.**/
     void documentChanged(KEduVocDocument *newDocument);
     void languagesChanged();
     void statesNeedSaving();
